@@ -1,5 +1,5 @@
 package App::ansifold;
-our $VERSION = "1.30";
+our $VERSION = "1.31";
 
 use v5.14;
 use warnings;
@@ -37,6 +37,7 @@ use Getopt::EX::Hashed 'has'; {
     has padchar    => '   =s  ' ;
     has prefix     => '   =s  ' ;
     has autoindent => '   =s  ' ;
+    has keepindent => '   !   ' ;
     has indentchar => '   =s  ' , default => ' ';
     has ambiguous  => '   =s  ' ;
     has paragraph  => ' p +   ' , default => 0;
@@ -248,15 +249,23 @@ sub doit {
 	    next if length == 0;
 	}
 	# chomp() does not remove single "\n" when $/ is "\n\n"
-	my $chomped = s/(\n+)\z// ? length $1 : 0;
+	my $chomped = s/(\R+)\z// ? $1 : '';
+	my $eol = $chomped =~ /\r/ ? "\r\n" : "\n";
 	fill_paragraph() if $app->refill;
 	if ($app->{indent_pat} && /^$app->{indent_pat}/p) {
-	    my $indent = ansi_width ${^MATCH};
+	    my $matched = ${^MATCH};
+	    my $indent = ansi_width $matched;
 	    if ($indent >= $app->min_width) {
 		die sprintf("%s\n%s\n%s\n", $_, ("^" x $indent),
 			    "ERROR: Autoindent pattern is longer than folding width.");
 	    }
-	    my $prefix = $app->indentchar x $indent;
+	    my $prefix = do {
+		if ($app->keepindent) {
+		    $matched;
+		} else {
+		    $app->indentchar x $indent;
+		}
+	    };
 	    $fold->configure(prefix => $prefix);
 	}
 	my @chops = $fold->text($_)->chops;
@@ -270,8 +279,8 @@ sub doit {
 	    @chops = grep { defined } @chops[@index];
 	}
 	print join $separator, @chops;
-	print "\n" x $chomped if $chomped;
-	print "\n" x $app->paragraph if $app->paragraph > 0;
+	print $chomped if $chomped;
+	print $eol x $app->paragraph if $app->paragraph > 0;
     }
 
     return $app;
